@@ -16,25 +16,22 @@
 
 package org.jbpm.workbench.ht.client.editors.taskslist;
 
-import java.util.Arrays;
-import java.util.Collections;
-import java.util.HashSet;
-import java.util.List;
-import java.util.Set;
+import java.util.*;
 import java.util.function.Predicate;
+
 import javax.enterprise.event.Event;
 
 import com.google.gwt.view.client.Range;
-import org.dashbuilder.common.client.error.ClientRuntimeError;
 import org.dashbuilder.dataset.DataSet;
 import org.dashbuilder.dataset.DataSetLookup;
-import org.dashbuilder.dataset.DataSetOp;
 import org.dashbuilder.dataset.client.DataSetReadyCallback;
 import org.dashbuilder.dataset.filter.ColumnFilter;
 import org.dashbuilder.dataset.filter.DataSetFilter;
+import org.jboss.errai.ioc.client.api.ManagedInstance;
 import org.jboss.errai.security.shared.api.identity.User;
 import org.jboss.errai.ui.client.local.spi.TranslationService;
 import org.jbpm.workbench.common.client.PerspectiveIds;
+import org.jbpm.workbench.common.client.dataset.ErrorHandlerBuilder;
 import org.jbpm.workbench.common.client.filters.active.ActiveFilterItem;
 import org.jbpm.workbench.common.client.filters.basic.BasicFilterAddEvent;
 import org.jbpm.workbench.common.client.filters.basic.BasicFilterRemoveEvent;
@@ -48,6 +45,8 @@ import org.jbpm.workbench.ht.model.events.TaskSelectionEvent;
 import org.jbpm.workbench.ht.service.TaskService;
 import org.junit.Before;
 import org.junit.Test;
+import org.kie.server.controller.api.model.spec.Capability;
+import org.kie.server.controller.api.model.spec.ServerTemplate;
 import org.mockito.ArgumentCaptor;
 import org.mockito.Mock;
 import org.mockito.Spy;
@@ -62,7 +61,11 @@ import org.uberfire.mocks.CallerMock;
 import org.uberfire.mocks.EventSourceMock;
 import org.uberfire.mvp.impl.DefaultPlaceRequest;
 
+import static java.util.Collections.emptyList;
+import static java.util.Collections.emptyMap;
+import static java.util.Collections.singletonList;
 import static org.dashbuilder.dataset.filter.FilterFactory.equalsTo;
+import static org.dashbuilder.dataset.filter.FilterFactory.in;
 import static org.dashbuilder.dataset.filter.FilterFactory.likeTo;
 import static org.jbpm.workbench.ht.client.util.TaskUtils.TaskType;
 import static org.jbpm.workbench.ht.client.util.TaskUtils.getStatusByType;
@@ -128,6 +131,14 @@ public abstract class AbstractTaskListPresenterTest {
     @Spy
     protected Event<TaskSelectionEvent> taskSelected = new EventSourceMock<TaskSelectionEvent>();
 
+    @Mock
+    protected ManagedInstance<ErrorHandlerBuilder> errorHandlerBuilder;
+
+    @Spy
+    protected ErrorHandlerBuilder errorHandler;
+
+    private String datasetUId = "dataserUId";
+
     protected static void testTaskStatusCondition(Predicate<TaskSummary> predicate,
                                                   String... validStatutes) {
         List<String> allStatus = getStatusByType(TaskType.ALL);
@@ -154,6 +165,7 @@ public abstract class AbstractTaskListPresenterTest {
         when(extendedPagedTable.getPageSize()).thenReturn(10);
         when(dataSetQueryHelper.getCurrentTableSettings()).thenReturn(filterSettings);
         when(filterSettings.getKey()).thenReturn("key");
+        when(filterSettings.getUUID()).thenReturn(datasetUId);
         when(perspectiveManager.getCurrentPerspective()).thenReturn(perspectiveActivity);
 
         //Mock that actually calls the callbacks
@@ -179,6 +191,9 @@ public abstract class AbstractTaskListPresenterTest {
                                                                 any(DataSetReadyCallback.class));
 
         when(identity.getIdentifier()).thenReturn("userId");
+
+        when(errorHandlerBuilder.get()).thenReturn(errorHandler);
+        doNothing().when(errorHandler).showErrorMessage(any());
     }
 
     protected abstract AbstractTaskListPresenter getPresenter();
@@ -241,26 +256,37 @@ public abstract class AbstractTaskListPresenterTest {
                                         TASK_ID);
     }
 
+    @Test
+    public void testRemoveActiveFilter() {
+        final String taskName = "taskName";
+        getPresenter().removeActiveFilter(equalsTo(COLUMN_NAME, taskName));
+
+        verify(viewMock).removeDomainSpecifColumns();
+
+        reset(viewMock);
+
+        getPresenter().removeActiveFilter(in(COLUMN_NAME, Arrays.asList(taskName)));
+
+        verify(viewMock, never()).removeDomainSpecifColumns();
+    }
+
     @Test
     public void isFilteredByTaskNameTest() {
         final String taskName = "taskName";
         final DataSetFilter filter = new DataSetFilter();
-        filter.addFilterColumn(equalsTo(COLUMN_NAME,
-                                        taskName));
+        filter.addFilterColumn(equalsTo(COLUMN_NAME, taskName));
 
-        final String filterTaskName = getPresenter().isFilteredByTaskName(Collections.<DataSetOp>singletonList(filter));
-        assertEquals(taskName,
-                     filterTaskName);
+        final String filterTaskName = getPresenter().isFilteredByTaskName(Collections.singletonList(filter));
+        assertEquals(taskName, filterTaskName);
     }
 
     @Test
     public void isFilteredByTaskNameInvalidTest() {
         final String taskName = "taskName";
         final DataSetFilter filter = new DataSetFilter();
-        filter.addFilterColumn(likeTo(COLUMN_DESCRIPTION,
-                                      taskName));
+        filter.addFilterColumn(likeTo(COLUMN_DESCRIPTION, taskName));
 
-        final String filterTaskName = getPresenter().isFilteredByTaskName(Collections.<DataSetOp>singletonList(filter));
+        final String filterTaskName = getPresenter().isFilteredByTaskName(Collections.singletonList(filter));
         assertNull(filterTaskName);
     }
 
@@ -303,11 +329,9 @@ public abstract class AbstractTaskListPresenterTest {
                                          5));
 
         ArgumentCaptor<Set> argument = ArgumentCaptor.forClass(Set.class);
-        verify(viewMock).addDomainSpecifColumns(any(ListTable.class),
-                                                argument.capture());
+        verify(viewMock).addDomainSpecifColumns(argument.capture());
 
-        assertEquals(expectedColumns,
-                     argument.getValue());
+        assertEquals(expectedColumns, argument.getValue());
 
         verify(dataSetQueryHelper).lookupDataSet(anyInt(),
                                                  any(DataSetReadyCallback.class));
@@ -329,9 +353,7 @@ public abstract class AbstractTaskListPresenterTest {
                                          5));
 
         argument = ArgumentCaptor.forClass(Set.class);
-        verify(viewMock,
-               times(2)).addDomainSpecifColumns(any(ListTable.class),
-                                                argument.capture());
+        verify(viewMock, times(2)).addDomainSpecifColumns(argument.capture());
 
         assertEquals(expectedColumns,
                      argument.getValue());
@@ -411,22 +433,6 @@ public abstract class AbstractTaskListPresenterTest {
         assertFalse(getPresenter().getProcessInstanceCondition().test(TaskSummary.builder().build()));
     }
 
-    @Test
-    public void testCreateDataSetTaskCallback() {
-        final AbstractTaskListPresenter presenter = spy(getPresenter());
-        final ClientRuntimeError error = new ClientRuntimeError("");
-        final FilterSettings filterSettings = mock(FilterSettings.class);
-        final DataSetReadyCallback callback = presenter.getDataSetReadyCallback(0,
-                                                                                filterSettings);
-
-        doNothing().when(presenter).showErrorPopup(any());
-
-        assertFalse(callback.onError(error));
-
-        verify(viewMock).hideBusyIndicator();
-        verify(presenter).showErrorPopup(Constants.INSTANCE.TaskListCouldNotBeLoaded());
-    }
-
     @Test
     public void testExitedTaskSelection() {
         TaskSummary taskSummary = TaskSummary.builder()
@@ -469,8 +475,9 @@ public abstract class AbstractTaskListPresenterTest {
                                                                        null,
                                                                        null);
         final ColumnFilter columnFilter = mock(ColumnFilter.class);
-        getPresenter().onBasicFilterAddEvent(new BasicFilterAddEvent(filter,
-                                                                columnFilter));
+        getPresenter().onBasicFilterAddEvent(new BasicFilterAddEvent(datasetUId,
+                                                                     filter,
+                                                                     columnFilter));
 
         verify(viewMock).addActiveFilter(filter);
         verify(filterSettings).addColumnFilter(columnFilter);
@@ -484,8 +491,9 @@ public abstract class AbstractTaskListPresenterTest {
                                                                        null,
                                                                        null);
         final ColumnFilter columnFilter = mock(ColumnFilter.class);
-        getPresenter().onBasicFilterRemoveEvent(new BasicFilterRemoveEvent(filter,
-                                                                      columnFilter));
+        getPresenter().onBasicFilterRemoveEvent(new BasicFilterRemoveEvent(datasetUId,
+                                                                           filter,
+                                                                           columnFilter));
 
         verify(viewMock).removeActiveFilter(filter);
         verify(filterSettings).removeColumnFilter(columnFilter);
@@ -506,7 +514,11 @@ public abstract class AbstractTaskListPresenterTest {
                 .build();
 
 
-        getPresenter().setSelectedServerTemplate(serverTemplateId);
+        getPresenter().setSelectedServerTemplate(new ServerTemplate(serverTemplateId,
+                                                                    null,
+                                                                    singletonList(Capability.PROCESS.name()),
+                                                                    emptyMap(),
+                                                                    emptyList()));
         getPresenter().selectSummaryItem(taskSummary);
 
         assertTrue(getPresenter().isSameTaskFromEvent().test(new TaskCompletedEvent(serverTemplateId,
@@ -533,7 +545,11 @@ public abstract class AbstractTaskListPresenterTest {
                 .build();
 
         final String serverTemplateId = "serverTemplateId";
-        getPresenter().setSelectedServerTemplate(serverTemplateId);
+        getPresenter().setSelectedServerTemplate(new ServerTemplate(serverTemplateId,
+                                                                    null,
+                                                                    singletonList(Capability.PROCESS.name()),
+                                                                    emptyMap(),
+                                                                    emptyList()));
         getPresenter().selectSummaryItem(taskSummary);
 
         getPresenter().onTaskCompletedEvent(new TaskCompletedEvent(serverTemplateId,
